(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    (global.Time = factory());
}(this, (function () { 'use strict';

    var months = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'],
        days = ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday'];
    function padStart(str, length, pad) {
        for (var i = 0; i < length - str.length; i++) {
            str = pad + str;
        }
        return str;
    }
    function getPostfix(date) {
        if ([11, 12, 13].includes(date)) {
            return 'th';
        } else {
            var x = +padStart(date.toString(), 2, '0')[1];
            switch (x) {
                case 1:
                    return 'st';
                case 2:
                    return 'nd';
                case 3:
                    return 'rd';
                default:
                    return 'th';

            }
        }
    }
    var replacers = {
        YYYY: function YYYY(date) {
            return date.getFullYear().toString();
        },
        YY: function YY(date) {
            return date.getFullYear().toString().slice(-2);
        },
        MMMM: function MMMM(date) {
            return months[date.getMonth()];
        },
        MMM: function MMM(date) {
            return months[date.getMonth()].slice(0, 3);
        },
        MM: function MM(date) {
            return padStart((date.getMonth() + 1).toString(), 2, '0');
        },
        M: function M(date) {
            return (date.getMonth() + 1).toString();
        },
        DD: function DD(date) {
            return padStart(date.getDate().toString(), 2, '0');
        },
        D: function D(date) {
            return date.getDate().toString();
        },
        dd: function dd(date) {
            var d = date.getDate();
            return padStart(d.toString(), 2, '0') + getPostfix(d);
        },
        d: function d(date) {
            var d = date.getDate();
            return d + getPostfix(d);
        },
        HH: function HH(date) {
            return padStart(date.getHours().toString(), 2, '0');
        },
        H: function H(date) {
            return date.getHours().toString();
        },
        hh: function hh(date) {
            return padStart((date.getHours() % 12).toString(), 2, '0');
        },
        h: function h(date) {
            return (date.getHours() % 12).toString();
        },
        mm: function mm(date) {
            return padStart(date.getMinutes().toString(), 2, '0');
        },
        m: function m(date) {
            return date.getMinutes().toString();
        },
        SS: function SS(date) {
            return padStart(date.getSeconds().toString(), 2, '0');
        },
        S: function S(date) {
            return date.getSeconds().toString();
        },
        sss: function sss(date) {
            return padStart(date.getMilliseconds().toString(), 3, '0');
        },
        ss: function ss(date) {
            return padStart(date.getMilliseconds().toString(), 2, '0').slice(0, 2);
        },
        s: function s(date) {
            return date.getMilliseconds().toString().slice(0, 1);
        },
        WW: function WW(date) {
            return days[date.getDay() - 1];
        },
        W: function W(date) {
            return days[date.getDay() - 1].slice(0, 3);
        },
        ww: function ww(date) {
            return padStart(date.getDay().toString(), 2, '0');
        },
        w: function w(date) {
            return date.getDay().toString();
        },
        A: function A(date) {
            return date.getHours() < 12 ? 'AM' : 'PM';
        },
        a: function a(date) {
            return date.getHours() < 12 ? 'am' : 'pm';
        }
    };

    var Time = {
        replacers: replacers,
        get: function get(format) {
            return Time.format(new Date(), format);
        },
        format: function format(date, _format) {
            var ans = _format;
            var ids = _format.match(/(\w)\1*/g);
            if (ids) {
                ids.forEach(function (id) {
                    var replacer = replacers[id];
                    if (replacer) {
                        ans = ans.replace(id, replacer(date));
                    }
                });
            }
            return ans;
        }
    };

    return Time;

})));
